@@ -1,8 +1,9 @@
+// Crate Name
 #![allow(non_snake_case)]
 
 use std::env;
 
-fn get_message() -> String {
+fn message_to_print_until_die() ->  String {
     let args: Vec<String> = env::args().skip(1).collect();
 
     if args.len() >= 1 {
@@ -13,9 +14,7 @@ fn get_message() -> String {
 }
 
 fn main() {
-    let print_until_dead = get_message();
-
     loop {
-        println!("{}", print_until_dead);
+        println!("{}", message_to_print_until_die());
     }
 }
